@@ -147,7 +147,7 @@ FloppyData::FloppyData(QWidget * parent)
         else {
             userFeedBack += i18nc( "Linux", "Program mkdosfs <b>not found</b>. MSDOS formatting <b>not available</b>." );
         }
-        userFeedBack += QStringLiteral( "<br>" );
+        userFeedBack += QLatin1String( "<br>" );
         if (Ext2Filesystem::runtimeCheck()) {
             filesystemComboBox->addItem(i18n("ext2"));
             ++numFileSystems;
@@ -156,7 +156,7 @@ FloppyData::FloppyData(QWidget * parent)
         else {
             userFeedBack += i18n( "Program mke2fs <b>not found</b>. Ext2 formatting <b>not available</b>" );
         }
-        userFeedBack += QStringLiteral( "<br>" );
+        userFeedBack += QLatin1String( "<br>" );
         if (MinixFilesystem::runtimeCheck()) {
             filesystemComboBox->addItem(i18n("Minix"));
             ++numFileSystems;
@@ -176,7 +176,7 @@ FloppyData::FloppyData(QWidget * parent)
         else {
             userFeedBack += i18nc( "BSD", "Program newfs_msdos <b>not found</b>. MSDOS formatting <b>not available</b>." );
         }
-        userFeedBack += QStringLiteral( "<br>" );
+        userFeedBack += QLatin1String( "<br>" );
         if (UFSFilesystem::runtimeCheck()) {
             filesystemComboBox->addItem(i18n("UFS"));
             ++numFileSystems;
@@ -185,7 +185,7 @@ FloppyData::FloppyData(QWidget * parent)
         else {
             userFeedBack += i18nc( "BSD", "Program newfs <b>not found</b>. UFS formatting <b>not available</b>." );
         }
-        userFeedBack += QStringLiteral( "<br>" );
+        userFeedBack += QLatin1String( "<br>" );
         if (Ext2Filesystem::runtimeCheck()) {
             filesystemComboBox->addItem(i18n("ext2"));
             ++numFileSystems;
@@ -223,7 +223,7 @@ FloppyData::FloppyData(QWidget * parent)
         v1->addWidget( buttongroup );
 
         // ### TODO: we need some user feedback telling why full formatting is disabled.
-        userFeedBack += QStringLiteral( "<br>" );
+        userFeedBack += QLatin1String( "<br>" );
         m_canLowLevel = FDFormat::runtimeCheck();
         if (m_canLowLevel){
             fullformat->setChecked(true);
@@ -234,7 +234,7 @@ FloppyData::FloppyData(QWidget * parent)
             quick->setChecked(true);
             userFeedBack += i18n( "Program fdformat <b>not found</b>. Full formatting <b>disabled</b>." );
         }
-        userFeedBack += QStringLiteral( "<br>" );
+        userFeedBack += QLatin1String( "<br>" );
         m_canZeroOut = DDZeroOut::runtimeCheck();
         if ( m_canZeroOut )
         {
@@ -320,8 +320,8 @@ FloppyData::FloppyData(QWidget * parent)
             i18n("<qt>This is the status window, where error messages are displayed.</qt>") );
 
         QString frameText( userFeedBack );
-        frameText.prepend( QStringLiteral( "<qt>" ) );
-        frameText.append( QStringLiteral( "</qt>" ) );
+        frameText.prepend( QLatin1String( "<qt>" ) );
+        frameText.append( QLatin1String( "</qt>" ) );
         frame->setText( frameText );
 
         ml->addWidget( frame );
@@ -339,11 +339,11 @@ FloppyData::FloppyData(QWidget * parent)
 	setWidgets();
     if (!numFileSystems) {
         QString errorMessage;
-        errorMessage += QStringLiteral( "<qt>" );
+        errorMessage += QLatin1String( "<qt>" );
         errorMessage += i18n("KFloppy cannot find any of the needed programs for creating file systems; please check your installation.<br /><br />Log:");
-        errorMessage += QStringLiteral( "<br>" );
+        errorMessage += QLatin1String( "<br>" );
         errorMessage += userFeedBack;
-        errorMessage += QStringLiteral( "</qt>" );
+        errorMessage += QLatin1String( "</qt>" );
         KMessageBox::error( this, errorMessage );
     }
 }
@@ -422,7 +422,7 @@ bool FloppyData::setInitialDevice(const QString& dev)
   QString newDevice = dev;
 
   QUrl url( newDevice );
-  if( url.isValid() && ( url.scheme() == QStringLiteral( "media" ) || url.scheme() == QStringLiteral( "system" ) ) ) {
+  if( url.isValid() && ( url.scheme() == QLatin1String( "media" ) || url.scheme() == QLatin1String( "system" ) ) ) {
     QString name = url.fileName();
 
     QDBusInterface mediamanager( QStringLiteral( "org.kde.kded" ), QStringLiteral( "/modules/mediamanager" ), QStringLiteral( "org.kde.MediaManager" ) );
@@ -436,9 +436,9 @@ bool FloppyData::setInitialDevice(const QString& dev)
   }
 
   int drive = -1;
-  if ( newDevice.startsWith(QStringLiteral( "/dev/fd0" )) )
+  if ( newDevice.startsWith(QLatin1String( "/dev/fd0" )) )
     drive = 0;
-  if ( newDevice.startsWith(QStringLiteral( "/dev/fd1" )))
+  if ( newDevice.startsWith(QLatin1String( "/dev/fd1" )))
     drive = 1;
 
   // ### TODO user given devices
@@ -510,7 +510,7 @@ void FloppyData::format(){
   frame->clear();
 
     const QString currentComboBoxDevice (  deviceComboBox->currentText() );
-    const bool userDevice = ( currentComboBoxDevice.startsWith (QStringLiteral( "/dev/" )) );
+    const bool userDevice = ( currentComboBoxDevice.startsWith (QLatin1String( "/dev/" )) );
 
 #ifdef ANY_BSD
     if ( userDevice && filesystemComboBox->currentText() != i18n("UFS"))
